@@ -369,6 +369,7 @@ class StaticWebsite(
         id: builtins.str,
         *,
         website_content_path: builtins.str,
+        default_website_bucket_encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
         default_website_bucket_encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
         distribution_props: typing.Optional[aws_cdk.aws_cloudfront.DistributionProps] = None,
         runtime_options: typing.Optional[RuntimeOptions] = None,
@@ -379,6 +380,7 @@ class StaticWebsite(
         :param scope: -
         :param id: -
         :param website_content_path: (experimental) Path to the directory containing the static website files and assets. This directory must contain an index.html file.
+        :param default_website_bucket_encryption: (experimental) Bucket encryption to use for the default bucket. Supported options are KMS or S3MANAGED. Note: If planning to use KMS, ensure you associate a Lambda Edge function to sign requests to S3 as OAI does not currently support KMS encryption. Refer to {@link https://aws.amazon.com/blogs/networking-and-content-delivery/serving-sse-kms-encrypted-content-from-s3-using-cloudfront/} Default: - "S3MANAGED"
         :param default_website_bucket_encryption_key: (experimental) A predefined KMS customer encryption key to use for the default bucket that gets created. Note: This is only used if the websiteBucket is left undefined, otherwise all settings from the provided websiteBucket will be used.
         :param distribution_props: (experimental) Custom distribution properties. Note: defaultBehaviour.origin is a required parameter, however it will not be used as this construct will wire it on your behalf. You will need to pass in an instance of StaticWebsiteOrigin (NoOp) to keep the compiler happy.
         :param runtime_options: (experimental) Dynamic configuration which gets resolved only during deployment.
@@ -389,6 +391,7 @@ class StaticWebsite(
         '''
         props = StaticWebsiteProps(
             website_content_path=website_content_path,
+            default_website_bucket_encryption=default_website_bucket_encryption,
             default_website_bucket_encryption_key=default_website_bucket_encryption_key,
             distribution_props=distribution_props,
             runtime_options=runtime_options,
@@ -463,6 +466,7 @@ class StaticWebsiteOrigin(
     jsii_struct_bases=[],
     name_mapping={
         "website_content_path": "websiteContentPath",
+        "default_website_bucket_encryption": "defaultWebsiteBucketEncryption",
         "default_website_bucket_encryption_key": "defaultWebsiteBucketEncryptionKey",
         "distribution_props": "distributionProps",
         "runtime_options": "runtimeOptions",
@@ -475,6 +479,7 @@ class StaticWebsiteProps:
         self,
         *,
         website_content_path: builtins.str,
+        default_website_bucket_encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
         default_website_bucket_encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
         distribution_props: typing.Optional[aws_cdk.aws_cloudfront.DistributionProps] = None,
         runtime_options: typing.Optional[RuntimeOptions] = None,
@@ -484,6 +489,7 @@ class StaticWebsiteProps:
         '''(experimental) Properties for configuring the StaticWebsite.
 
         :param website_content_path: (experimental) Path to the directory containing the static website files and assets. This directory must contain an index.html file.
+        :param default_website_bucket_encryption: (experimental) Bucket encryption to use for the default bucket. Supported options are KMS or S3MANAGED. Note: If planning to use KMS, ensure you associate a Lambda Edge function to sign requests to S3 as OAI does not currently support KMS encryption. Refer to {@link https://aws.amazon.com/blogs/networking-and-content-delivery/serving-sse-kms-encrypted-content-from-s3-using-cloudfront/} Default: - "S3MANAGED"
         :param default_website_bucket_encryption_key: (experimental) A predefined KMS customer encryption key to use for the default bucket that gets created. Note: This is only used if the websiteBucket is left undefined, otherwise all settings from the provided websiteBucket will be used.
         :param distribution_props: (experimental) Custom distribution properties. Note: defaultBehaviour.origin is a required parameter, however it will not be used as this construct will wire it on your behalf. You will need to pass in an instance of StaticWebsiteOrigin (NoOp) to keep the compiler happy.
         :param runtime_options: (experimental) Dynamic configuration which gets resolved only during deployment.
@@ -501,6 +507,8 @@ class StaticWebsiteProps:
         self._values: typing.Dict[str, typing.Any] = {
             "website_content_path": website_content_path,
         }
+        if default_website_bucket_encryption is not None:
+            self._values["default_website_bucket_encryption"] = default_website_bucket_encryption
         if default_website_bucket_encryption_key is not None:
             self._values["default_website_bucket_encryption_key"] = default_website_bucket_encryption_key
         if distribution_props is not None:
@@ -524,6 +532,23 @@ class StaticWebsiteProps:
         assert result is not None, "Required property 'website_content_path' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def default_website_bucket_encryption(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_s3.BucketEncryption]:
+        '''(experimental) Bucket encryption to use for the default bucket.
+
+        Supported options are KMS or S3MANAGED.
+
+        Note: If planning to use KMS, ensure you associate a Lambda Edge function to sign requests to S3 as OAI does not currently support KMS encryption. Refer to {@link https://aws.amazon.com/blogs/networking-and-content-delivery/serving-sse-kms-encrypted-content-from-s3-using-cloudfront/}
+
+        :default: - "S3MANAGED"
+
+        :stability: experimental
+        '''
+        result = self._values.get("default_website_bucket_encryption")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketEncryption], result)
+
     @builtins.property
     def default_website_bucket_encryption_key(
         self,
